# NAME

GitLab - convenience wrapper for [GitLab::API](pod-GitLab-api.md) that provides useful constants

# SYNOPSIS

```{.pl}
use GitLab qw(:utils);

my $gitlab = GitLab::API->new(...);
my $users  = $gitlab->users();
```

# DESCRIPTION

## Constants

The module defines access level constants. See appropriate API documentation
for explanation.

### Group visibility

Import with `:group_visibility` tag.

| code  | constant               |
| ----: | ---------------------- |
| 10    | `GROUP_PRIVATE`        |
| 20    | `GROUP_INTERNAL`       |
| 30    | ` GROUP_PUBLIC`        |

### Member access

Import with `:member_access` tag.

| code  | constant               |
| ----: | ---------------------- |
| 10    | `MEMBER_GUEST`         |
| 20    | `MEMBER_REPORTER`      |
| 30    | `MEMBER_DEVELOPER`     |
| 40    | `MEMBER_MASTER`        |
| 50    | `MEMBER_OWNER`         |

## Utilities

Import with `:utils` tag.

- `group_visibility_name()`

    ```{.pl}
    $name = GitLab::group_visibility_name($code);
    ```

    Translates a Group Visibility code to its string representation, i.e. _Private_, _Internal_ or _Public_.
    If the parameter does not represent a valid GitLab Group Visibility code, returns _Invalid_.

- `member_access_name()`

    ```{.pl}
    $name = GitLab::member_access_name($code);
    ```

    Translates a Member Access code to its string representation, i.e. _Guest_, _Reporter_, _Developer_, _Master_ and _Owner_.
    If the parameter does not represent a valid GitLab Member Access code, returns _Invalid_.

# AUTHOR

Roman Lacko <[xlacko1@fi.muni.cz](https://metacpan.org/pod/xlacko1@fi.muni.cz)>

# SEE ALSO

- [GitLab::API::v3](https://metacpan.org/pod/GitLab::API::v3)

    Complete GitLab API v3 implementation with CLI support.

- [GitLab::API](pod-GitLab-API.md)

    implementation of the [GitLab API](http://docs.gitlab.com/ce/api/) client.

- [GitLab::Groups](pod-GitLab-Groups.md)

    [GitLab Groups](http://docs.gitlab.com/ce/api/groups.html) methods.

- [GitLab::Namespaces](pod-GitLab-Namespaces.md)

    [GitLab Namespaces](http://docs.gitlab.com/ce/api/namespaces.html) methods.

- [GitLab::Users](pod-GitLab-Users.md)

    [GitLab Users](http://docs.gitlab.com/ce/api/users.html) methods.
